Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@pandora.be>2011-10-13 03:03:12 +0400
committerBrecht Van Lommel <brechtvanlommel@pandora.be>2011-10-13 03:03:12 +0400
commit9ebfcea8f392a0ac91247973d2e9ee06f689799c (patch)
tree48ee1910bbe7156e262fd2329dc8346c1e314bfa /intern/cycles/render/shader.h
parent310b25c388aeaf43eeb4b0e4895cc5a24e44cd8e (diff)
Cycles: revert commit that joined surface/volume socket into a single shader socket,
on second thought this makes it a bit too difficult to understand what's going on.
Diffstat (limited to 'intern/cycles/render/shader.h')
-rw-r--r--intern/cycles/render/shader.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/intern/cycles/render/shader.h b/intern/cycles/render/shader.h
index 17ffc75924b..45efa123ef6 100644
--- a/intern/cycles/render/shader.h
+++ b/intern/cycles/render/shader.h
@@ -39,8 +39,8 @@ struct float3;
/* Shader describing the appearance of a Mesh, Light or Background.
*
* While there is only a single shader graph, it has two outputs: shader,
* displacement, that the shader manager will compile and execute
* separately. */
class Shader {
@@ -65,10 +65,11 @@ public:
bool need_update_attributes;
/* information about shader after compiling */
+ bool has_surface;
bool has_surface_emission;
bool has_surface_transparent;
- bool has_displacement;
bool has_volume;
+ bool has_displacement;
/* requested mesh attributes */
AttributeRequestSet attributes;
@@ -39,8 +39,8 @@ struct float3;
/* Shader describing the appearance of a Mesh, Light or Background.
*
- * While there is only a single shader graph, it has two outputs: shader,
- * displacement, that the shader manager will compile and execute
+ * While there is only a single shader graph, it has three outputs: surface,
+ * volume and displacement, that the shader manager will compile and execute
* separately. */
class Shader {